@@ -12,13 +12,13 @@ UA = 'isbnlib (gzip)'
 SERVICE_URL = (
     'https://www.googleapis.com/books/v1/volumes?q=isbn:{isbn}'
     '&fields=items/volumeInfo(title,subtitle,authors,publisher,publishedDate,'
-    'language,industryIdentifiers)&maxResults=1')
+    'language,industryIdentifiers,description,imageLinks)&maxResults=1')
 LOGGER = logging.getLogger(__name__)
 
 
 # pylint: disable=broad-except
 def _mapper(isbn, records):
-    """Mapp: canonical <- records."""
+    """Map: canonical <- records."""
     # canonical: ISBN-13, Title, Authors, Publisher, Year, Language
     try:
         canonical = {}
@@ -38,7 +38,7 @@ def _mapper(isbn, records):
     except Exception:  # pragma: no cover
         LOGGER.debug('RecordMappingError for %s with data %s', isbn, records)
         raise RecordMappingError(isbn)
-    # call stdmeta for extra cleanning and validation
+    # call stdmeta for extra cleaning and validation
     return stdmeta(canonical)
 
 
@@ -58,7 +58,9 @@ def _records(isbn, data):
                 ids):  # pragma: no cover
             LOGGER.debug('ISBNNotConsistentError for %s (%s)', isbn, repr(ids))
             raise ISBNNotConsistentError('{0} not in {1}'.format(
-                isbn, repr(ids)))
+                isbn,
+                repr(ids),
+            ))
     else:
         return {}  # pragma: no cover
     # map canonical <- records
